import java.util.*;
import java.io.*;

/**
 * Write a HighScores here.
 *
 * @author Chris Thiel, OFMCap
 * @version May 10, 2023
 */
public class HighScores
{
    // instance variables - replace the example below with your own
    private String fileName;
    private ArrayList<Score> scores;

    public HighScores(String fileName)
    {
        this.fileName = fileName;
        scores = new ArrayList<Score>();
        readFile();
        Collections.sort(scores); // descending order
    }

    public void readFile() 
    {
        File highScoreFile = new File(fileName);
        if (highScoreFile.exists()) {
            try {
                Scanner myReader = new Scanner(highScoreFile);
                while (myReader.hasNextLine()) {
                    String data = myReader.nextLine();
                    scores.add(new Score(data));
                    //System.out.println(data);
                }
                myReader.close();
            } catch (IOException e) {
                //System.out.println("Problem reading file.");
                e.printStackTrace();
            }
        } else {
            //System.out.println("The file does not exist.");
            try{
                highScoreFile.createNewFile();
            }catch(IOException e) {
                e.printStackTrace();
            }
            
        }
    }
    public void writeFile()
    {
        Collections.sort(scores);
        try {
            Writer wr = new FileWriter(fileName);
            for(Score s:scores)
                  wr.write(s.getScore()+":"+s.getName()+"\n");
            wr.flush();
            wr.close();
        } catch (IOException e)
        {
            e.printStackTrace();
        }
        
    }
    public void addScore(int score, String name)
    {
        scores.add(new Score(score, name));
        writeFile();
    }
    public String top(int n){
        Collections.sort(scores);
        String str="\nTop "+n+" Scores:\n";
        int i = 0;
        while (i < scores.size() && i< 10 )
        {
            Score s = scores.get(i);
            str += (i+1)+ ": " + s.getScore() + " by " + s.getName() + "\n";
            i++;
        }
        return str;
    }
    public String toString(){
        Collections.sort(scores);
        String str="";
        for(Score s:scores)
        {
            str += s.getScore() + " by " + s.getName() + "\n";
        }
        return str;
    }
}
